.. Pyrepo documentation master file, created by
   sphinx-quickstart on Sun May 18 23:24:58 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Pyrepo: Python Repository Abstraction
=====================================

Pyrepo is a repository abstraction package which provides a Python API for fetching and managing a variety of repositories.

Features
--------

* Support for repositories managed by commands
    * `Git <http://git-scm.com/>`_
* Supports source hosts:
    * `github.com <https://github.com/>`_
    * `bitbucket.org <https://bitbucket.org/>`_
* Utility to map import paths to repositories


User Guide
----------

This part of the documentation describes Pyrepo and how to get started using it to interact with repositories.

.. toctree::
   :maxdepth: 2

   intro
   install
   usage

API
---

.. toctree::
    :maxdepth: 2

    api

